@@ -495,7 +495,7 @@ class NodeManager:
             await config_data.update_java_path(JAVA_EXECUTABLE)
 
         if all_data["use_bundled_pylav_external"]:
-            await self._process_bundled_node_london(nodes_list)
+            # await self._process_bundled_node_london(nodes_list)
             await self._process_bundled_node_ny(nodes_list)
 
         tasks = [asyncio.create_task(n.wait_until_ready()) for n in nodes_list]
